==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggwidgetreloading.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Reloading widgets
//

#ifndef IGGWIDGETRELOADING_H
#define IGGWIDGETRELOADING_H


#include "iggwidgetkeybutton.h"
#include "iggwidgetkeyselectionbox.h"
#include "iggwidgetkeyslider.h"
#include "iggwidgetotherbutton.h"


class iDataInfo;


class iggWidgetReloadingRadioBox : public iggWidgetKeyRadioBox
{

public:

	iggWidgetReloadingRadioBox(const iDataInfo &info, const iString &title, const iObjectKey &key, iggFrame *parent);

protected:

	virtual void OnInt1Body(int i);

	const iDataInfo &mInfo;
};


class iggWidgetReloadingSlider : public iggWidgetKeyIntSlider
{

public:

	iggWidgetReloadingSlider(const iDataInfo &info, int min, int max, int numdig, const iString &title, const iObjectKey &key, iggFrame *parent, int index = -1);

protected:

	virtual void OnVoid1Body();

	const iDataInfo &mInfo;
};


class iggWidgetReloadingCheckBox : public iggWidgetKeyCheckBox
{

public:

	iggWidgetReloadingCheckBox(const iDataInfo &info, const iString &title, const iObjectKey &key, iggFrame *parent);

protected:

	virtual void OnVoid1Body();

	const iDataInfo &mInfo;
};


class iggWidgetReloadingPushButton : public iggWidgetSimpleButton
{

public:

	iggWidgetReloadingPushButton(const iString &title, iggFrame *parent);

protected:

	virtual bool UpdateWidgetBody();
	virtual void Execute();
};

#endif

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggwidgetreloading.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Reloading widgets
//

#ifndef IGGWIDGETRELOADING_H
#define IGGWIDGETRELOADING_H


#include "iggwidgetkeybutton.h"
#include "iggwidgetkeyselectionbox.h"
#include "iggwidgetkeyslider.h"
#include "iggwidgetotherbutton.h"


class iDataInfo;


class iggWidgetReloadingRadioBox : public iggWidgetKeyRadioBox
{

public:

	iggWidgetReloadingRadioBox(const iDataInfo &info, const iString &title, const iObjectKey &key, iggFrame *parent);

protected:

	virtual void OnInt1Body(int i);

	const iDataInfo &mInfo;
};


class iggWidgetReloadingSlider : public iggWidgetKeyIntSlider
{

public:

	iggWidgetReloadingSlider(const iDataInfo &info, int min, int max, int numdig, const iString &title, const iObjectKey &key, iggFrame *parent, int index = -1);

protected:

	virtual void OnVoid1Body();

	const iDataInfo &mInfo;
};


class iggWidgetReloadingCheckBox : public iggWidgetKeyCheckBox
{

public:

	iggWidgetReloadingCheckBox(const iDataInfo &info, const iString &title, const iObjectKey &key, iggFrame *parent);

protected:

	virtual void OnVoid1Body();

	const iDataInfo &mInfo;
};


class iggWidgetReloadingPushButton : public iggWidgetSimpleButton
{

public:

	iggWidgetReloadingPushButton(const iString &title, iggFrame *parent);

protected:

	virtual void UpdateWidgetBody();
	virtual void Execute();
};

#endif
